/*Draws horizontal zones on chart
 * Copyright (c) 2010, 2014 TradertoolsFX
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:

 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.

 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
#property copyright "date"
#property link      "someplace.com"
#property version   ". Draw Horizontal Line Zones"
extern string Version = "Horizontal Zone Script";

#property description "Add up to 10 price levels seperated by a comma. "
//#property show_inputs

#include "LineDrawer.mqh"

// User Parameters
extern string _desc1 = "===Price(s) separated by comma (or Delimiter, if changed from default)===";
extern string _desc4 = "List of DAX ones to add  ,9400,9450,9550,9600,9650,9700,9750,9800";

extern string PricePointList = 9500,9400,9450,9550,9600,9650,9700,9750,9800;
extern string Delimiter = ",";
extern string _desc2 = "===Enter Line* parameters below===";
extern int    LineWidth = 1;
extern ENUM_LINE_STYLE LineStyle = 0;
extern color  LineColor = clrDarkBlue;
extern string LineNamePrefix = "SRLine_";
extern string _desc3 = "===Enter zone parameters below==";
extern bool   UseZone = true;
extern double ZoneRangePips = 500;
extern bool   ZoneFill = true;
extern int    ZoneLineWidth = 1;
extern ENUM_LINE_STYLE ZoneLineStyle = 2;
extern color  ZoneColor = clrGold;

int start()
{
    // Adjust pip values for 5 digit pricing
    if (Digits() == 5 || Digits() == 3) {
        ZoneRangePips *= 10;
    }

    ObjectProperties line_props(LineWidth, LineStyle, LineColor);
    ZoneSettings zone_settings(line_props, UseZone, ZoneFill, ZoneRangePips);

    ushort del = StringGetChar(Delimiter, 0);
    string price_points[];
    int num_points = StringSplit(PricePointList, del, price_points);
    trim_strings(price_points, num_points);
    LineDrawer drawer(line_props, zone_settings, LineNamePrefix);
    double price;

    for (int i = 0; i < num_points; i++) {
        if (!is_valid_price_input(price_points[i])) {
            Alert(
                StringFormat(
                    "Skipping invalid price entered in PricePointList: '%s'",
                    price_points[i]
                )
            );
        } else {
            price = StringToDouble(price_points[i]);
            drawer.set_line_price(price);
            drawer.draw();
        }
    }

    return 0;
}

bool is_valid_price_input(string price_str)
{
    // Price should be a positive number.
    bool dot_found = false;
    uchar charcode = 0;
    for (int i = 0; i < StringLen(price_str); i++) {
        charcode = StringGetChar(price_str, i);
        if (charcode < '0' || charcode > '9') {
            if (charcode == '.' &&
                    !dot_found) {
                dot_found = true;
            } else {
                return false;
            }
        }
    }

    return true;
}

void trim_strings(string &strings[], int num_strings)
{
    for (int i = 0; i < num_strings; i++) {
        strings[i] = StringTrimLeft(strings[i]);
        strings[i] = StringTrimRight(strings[i]);
    }
}
